@@ -13,7 +13,7 @@ guess_value <- function(df) {
   if ("(all)" %in% names(df)) return("(all)")
   
   last <- names(df)[ncol(df)]
-  message("Using ", last, " as value column: use value_var to override.")
+  message("Using ", last, " as value column: use value.var to override.")
   
   last
 }
